"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const parcel_bundler_1 = tslib_1.__importDefault(require("parcel-bundler"));
const glob_1 = tslib_1.__importDefault(require("glob"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const isTestRunner = process.env.NODE_ENV === "test";
exports.bundle = (stasisConfig) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    // lookup files to bundle
    let files;
    if (Array.isArray(stasisConfig.entryAssets)) {
        files = stasisConfig.entryAssets.reduce((res, value, index) => {
            const f = glob_1.default.sync(value, {
                cwd: stasisConfig.basePath +
                    "/" +
                    stasisConfig.sourcePath +
                    "/" +
                    stasisConfig.assetsPath
            });
            return (res = [...res, ...f]);
        }, []);
    }
    else {
        files = glob_1.default.sync(stasisConfig.entryAssets, {
            cwd: stasisConfig.basePath +
                "/" +
                stasisConfig.sourcePath +
                "/" +
                stasisConfig.assetsPath
        });
    }
    // create bundler options
    const options = {
        outDir: stasisConfig.basePath +
            "/" +
            stasisConfig.publicPath +
            "/" +
            stasisConfig.assetsPath,
        cache: false,
        target: "browser",
        sourceMaps: false,
        logLevel: 1,
        detailedReport: false,
        watch: false
    };
    const entryFiles = files.map(f => stasisConfig.basePath +
        "/" +
        stasisConfig.sourcePath +
        "/" +
        stasisConfig.assetsPath +
        "/" +
        f);
    const bundler = new parcel_bundler_1.default(entryFiles, options);
    const startTime = process.hrtime();
    yield bundler.bundle(stasisConfig);
    // tslint:disable-next-line no-unused-expression
    !isTestRunner && console.log(chalk_1.default.green("Building bundle..."));
    // display build time
    const timeDiff = process.hrtime(startTime);
    const duration = timeDiff[0] * 1000 + timeDiff[1] / 1e6;
    // tslint:disable-next-line no-unused-expression
    !isTestRunner &&
        console.log(chalk_1.default.green(`Bundle built successfully in ${duration}ms`));
    return;
});
