"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const glob_1 = tslib_1.__importDefault(require("glob"));
const path_1 = tslib_1.__importDefault(require("path"));
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const handlebars_1 = tslib_1.__importDefault(require("handlebars"));
const fs_extra_promise_1 = tslib_1.__importDefault(require("fs-extra-promise"));
class HandlebarsEngine {
    constructor(options) {
        this.options = options;
        const partials = glob_1.default.sync("**/*.@(hbs|handlebars)", {
            cwd: options.partialsDir
        });
        partials.map((p) => {
            const { name } = path_1.default.parse(p);
            handlebars_1.default.registerPartial(name, fs_extra_1.default.readFileSync(options.partialsDir + "/" + p, { encoding: "utf8" }));
        });
        const helpers = glob_1.default.sync("**/*.js", { cwd: options.helpersDir });
        // Read handlebars helpers from /helpers directory.
        helpers.map((h) => {
            const { name } = path_1.default.parse(h);
            const relativeRequirePath = path_1.default.relative(__dirname, options.helpersDir + "/" + h);
            handlebars_1.default.registerHelper(name, require(relativeRequirePath));
        });
        this.cache = {};
    }
    render(props) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const tpl = yield this.getTemplate(props.meta.layout);
            const template = handlebars_1.default.compile(tpl);
            return template(props);
        });
    }
    getTemplate(layout) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const templatePath = this.options.layoutsDir + "/" + (layout ? layout + ".hbs" : "base.hbs");
            let tplString;
            if (this.cache[templatePath]) {
                tplString = this.cache[templatePath];
            }
            else {
                tplString = yield fs_extra_promise_1.default.readFileAsync(this.options.layoutsDir + "/" + (layout ? layout + ".hbs" : "base.hbs"), { encoding: "utf8" });
                this.cache[templatePath] = tplString;
            }
            return tplString;
        });
    }
}
exports.HandlebarsEngine = HandlebarsEngine;
