"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const slug_1 = tslib_1.__importDefault(require("slug"));
class Page {
    constructor(content, data, excerpt = "", pageName, destinationPath) {
        this.content = content;
        this.data = data;
        this.excerpt = excerpt;
        this.pageName = pageName;
        this.destinationPath = destinationPath;
    }
    htmlContent() {
        return this.content;
    }
    getName() {
        return this.pageName;
    }
    getSlug() {
        return slug_1.default(this.pageName.toLowerCase());
    }
    getDestinationPath() {
        const firstSegment = !this.destinationPath || this.destinationPath === "/"
            ? ""
            : this.destinationPath;
        if (this.pageName !== "index") {
            return `${firstSegment}/${this.getSlug()}/index.html`;
        }
        else {
            return `${firstSegment}/index.html`;
        }
    }
    getMeta() {
        return this.data;
    }
    getExcerpt() {
        return this.excerpt;
    }
    serialize(publicPath, active = false) {
        // Create path relative to output dir. Can be used to produce links to pages
        const relativePath = this.getDestinationPath().replace(publicPath, "");
        return {
            meta: this.getMeta(),
            excerpt: this.getExcerpt(),
            relativePath,
            active
        };
    }
}
exports.Page = Page;
