"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chokidar_1 = tslib_1.__importDefault(require("chokidar"));
const debounce_1 = tslib_1.__importDefault(require("lodash/debounce"));
const bundler_1 = require("./bundler");
const compiler_1 = require("./compiler");
const micro_1 = tslib_1.__importDefault(require("micro"));
const serve_handler_1 = tslib_1.__importDefault(require("serve-handler"));
const opn_1 = tslib_1.__importDefault(require("opn"));
const range_1 = tslib_1.__importDefault(require("lodash/range"));
const get_port_1 = tslib_1.__importDefault(require("get-port"));
exports.startServer = (stasisConfig, flags) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const srcPath = stasisConfig.basePath + "/" + stasisConfig.sourcePath;
    const options = {
        public: stasisConfig.basePath + "/" + stasisConfig.publicPath,
        srcPath: stasisConfig.basePath + "/" + stasisConfig.sourcePath,
        assetsPath: srcPath + "/" + stasisConfig.assetsPath
    };
    const server = micro_1.default((request, response) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        return serve_handler_1.default(request, response, {
            cleanUrls: true,
            trailingSlash: false,
            public: options.public
        });
    }));
    const pageWatcher = chokidar_1.default.watch(options.srcPath, {
        ignoreInitial: true,
        ignored: options.assetsPath
    });
    pageWatcher.on("all", debounce_1.default(() => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield compiler_1.compiler(stasisConfig);
    }), 500));
    const assetWatcher = chokidar_1.default.watch(options.assetsPath, {
        ignoreInitial: true
    });
    assetWatcher.on("all", debounce_1.default(() => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield bundler_1.bundle(stasisConfig);
    }), 500));
    // Get a free port - Prefer port 3000
    const freePort = yield get_port_1.default({ port: [...range_1.default(3000, 3100, 1)] });
    server.listen(freePort, () => {
        opn_1.default("http://localhost:" + freePort);
        console.log("Running at http://localhost:" + freePort);
    });
});
