"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const compiler_1 = require("../../lib/compiler");
const assert_1 = tslib_1.__importDefault(require("assert"));
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const path_1 = tslib_1.__importDefault(require("path"));
const bundler_1 = require("../../lib/bundler");
function fileExists(pathString) {
    return new Promise((resolve, reject) => {
        fs_extra_1.default.exists(pathString, exists => {
            if (exists) {
                resolve(exists);
                return;
            }
            else {
                reject(new Error("File does not exists although it should"));
            }
        });
    });
}
function fileNotExists(pathString) {
    return new Promise((resolve, reject) => {
        fs_extra_1.default.exists(pathString, exists => {
            if (exists) {
                reject(new Error("File exists although it should not"));
                return;
            }
            else {
                resolve(exists);
            }
        });
    });
}
const configFilePath = path_1.default.resolve(__dirname, "../fixtures/test-project/stasis.config.json");
function testClearDistDirectory() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const config = yield utils_1.parseConfigFile(configFilePath);
            try {
                yield fs_extra_1.default.mkdirp(config.basePath + "/" + config.publicPath);
                yield fs_extra_1.default.writeFile(config.basePath + "/" + config.publicPath + "/" + "test.txt", "test", { encoding: "utf8" });
                yield compiler_1.compiler(config);
                yield fileNotExists(config.basePath + "/" + config.publicPath + "/" + "test.txt");
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It clears the output directory before adding pages",
        run
    };
}
exports.testClearDistDirectory = testClearDistDirectory;
function testRendersPageWithDefaultLayout() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const config = yield utils_1.parseConfigFile(configFilePath);
            try {
                yield compiler_1.compiler(config);
                const page = yield fs_extra_1.default.readFile(config.basePath + "/" + config.publicPath + "/" + "index.html", "utf8");
                const checkString = `<li><a href="/docs">Docs Page</a>`;
                assert_1.default(page.indexOf(checkString) > 0);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It renders a page with the default layout",
        run
    };
}
exports.testRendersPageWithDefaultLayout = testRendersPageWithDefaultLayout;
function testRendersPageWithCustomLayout() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const config = yield utils_1.parseConfigFile(configFilePath);
            try {
                yield compiler_1.compiler(config);
                const page = yield fs_extra_1.default.readFile(config.basePath + "/" + config.publicPath + "/docs/" + "index.html", "utf8");
                const checkString = `<custom-layout></custom-layout>`;
                assert_1.default(page.indexOf(checkString) > 0);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It renders a page with a custom layout",
        run
    };
}
exports.testRendersPageWithCustomLayout = testRendersPageWithCustomLayout;
function testGeneratesPrettyUrls() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const config = yield utils_1.parseConfigFile(configFilePath);
            try {
                yield compiler_1.compiler(config);
                yield fileExists(config.basePath + "/" + config.sourcePath + "/pages/" + "page-one.md");
                yield fileExists(config.basePath + "/" + config.publicPath + "/page-one/" + "index.html");
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It generates an index.html file inside a folder with the slug name of the original file",
        run
    };
}
exports.testGeneratesPrettyUrls = testGeneratesPrettyUrls;
function testBundlerPicksUpFiles() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const config = yield utils_1.parseConfigFile(configFilePath);
            try {
                yield bundler_1.bundle(config);
                // check if files exists
                yield fileExists(config.basePath +
                    "/" +
                    config.sourcePath +
                    "/" +
                    config.assetsPath +
                    "/" +
                    "main.scss");
                yield fileExists(config.basePath +
                    "/" +
                    config.publicPath +
                    "/" +
                    config.assetsPath +
                    "/" +
                    "main.css");
                // check if file has been processed by a bundler
                const expected = yield fs_extra_1.default.readFile(path_1.default.resolve(__dirname, "fixtures/expected_main_css.css"), "utf8");
                const css = yield fs_extra_1.default.readFile(config.basePath +
                    "/" +
                    config.publicPath +
                    "/" +
                    config.assetsPath +
                    "/" +
                    "main.css", "utf8");
                assert_1.default.equal(css, expected, "File not transpiled");
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It picks up files from the assets folder",
        run
    };
}
exports.testBundlerPicksUpFiles = testBundlerPicksUpFiles;
function testCopyStaticFolder() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const config = yield utils_1.parseConfigFile(configFilePath);
            try {
                yield bundler_1.bundle(config);
                // check if files exists
                yield fileExists(config.basePath +
                    "/" +
                    config.sourcePath +
                    "/" +
                    config.staticPath +
                    "/" +
                    "demo.png");
                yield fileExists(config.basePath +
                    "/" +
                    config.publicPath +
                    "/" +
                    config.staticPath +
                    "/" +
                    "demo.png");
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It copies static asset folder",
        run
    };
}
exports.testCopyStaticFolder = testCopyStaticFolder;
