"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const compiler_test_1 = require("./compiler.test");
const page_test_1 = require("./page.test");
const utils_test_1 = require("./utils.test");
/**
 *
 * @param tCase Promise<boolean>
 */
function test(tCase) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            console.log(chalk_1.default.gray(tCase.description));
            const result = yield tCase.run();
            if (result) {
                console.log(chalk_1.default.green("success"));
            }
            else {
                console.log(chalk_1.default.red(tCase.description));
            }
            return result;
        }
        catch (e) {
            console.error(chalk_1.default.red(e.message));
            console.error(e.stack);
        }
    });
}
exports.test = test;
function executeSyncTests(testCases) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        for (const i of testCases) {
            try {
                yield test(i);
            }
            catch (e) {
                console.error(chalk_1.default.red(e.message));
                console.error(e.stack);
            }
        }
    });
}
exports.executeSyncTests = executeSyncTests;
(() => tslib_1.__awaiter(this, void 0, void 0, function* () {
    try {
        yield executeSyncTests([utils_test_1.testLoadRaptorConfig()]);
        yield executeSyncTests([compiler_test_1.testClearDistDirectory()]);
        yield executeSyncTests([
            compiler_test_1.testRendersPageWithDefaultLayout(),
            compiler_test_1.testRendersPageWithCustomLayout(),
            compiler_test_1.testGeneratesPrettyUrls(),
            /* testBundlerPicksUpFiles(), */
            compiler_test_1.testCopyStaticFolder(),
            page_test_1.testPageDestinationPath(),
            page_test_1.testPageSlug()
        ]);
    }
    catch (e) {
        throw e;
    }
}))();
