"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const assert_1 = tslib_1.__importDefault(require("assert"));
const page_1 = require("../../lib/page");
const mockPage = {
    content: "<h1>test</h1>",
    data: {
        title: "test"
    },
    excerpt: "<p>excerpt</p>",
    pageName: "Test Page",
    destinationPath: "/"
};
function testPageDestinationPath() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const page = new page_1.Page(mockPage.content, mockPage.data, mockPage.excerpt, mockPage.pageName, mockPage.destinationPath);
            const page1 = new page_1.Page(mockPage.content, mockPage.data, mockPage.excerpt, mockPage.pageName, "");
            const page2 = new page_1.Page(mockPage.content, mockPage.data, mockPage.excerpt, mockPage.pageName, "/sub-folder");
            try {
                assert_1.default(page.getDestinationPath() === "/test-page/index.html", `Unexpected destination path: ${page.getDestinationPath()} !== /test-page/index.html`);
                assert_1.default(page1.getDestinationPath() === "/test-page/index.html", `Unexpected destination path: ${page1.getDestinationPath()} !== /test-page/index.html`);
                assert_1.default(page2.getDestinationPath() === "/sub-folder/test-page/index.html", `Unexpected destination path: ${page2.getDestinationPath()} !== /sub-folder/test-page/index.html`);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It should handle page destination paths",
        run
    };
}
exports.testPageDestinationPath = testPageDestinationPath;
function testPageSlug() {
    function run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const page = new page_1.Page(mockPage.content, mockPage.data, mockPage.excerpt, mockPage.pageName, mockPage.destinationPath);
            const page1 = new page_1.Page(mockPage.content, mockPage.data, mockPage.excerpt, "TEST NAME", mockPage.destinationPath);
            try {
                assert_1.default(page.getSlug() === "test-page", `Unexpected slug: ${page.getSlug()} !== test-page`);
                assert_1.default(page1.getSlug() === "test-name", `Unexpected slug: ${page1.getSlug()} !== test-name`);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    return {
        description: "It should page slugs",
        run
    };
}
exports.testPageSlug = testPageSlug;
